@@ -31,6 +31,13 @@ __all__ = (
     "AllowedMethodsTypeDef",
     "CacheBehaviorTypeDef",
     "CacheBehaviorsTypeDef",
+    "CachePolicyConfigTypeDef",
+    "CachePolicyCookiesConfigTypeDef",
+    "CachePolicyHeadersConfigTypeDef",
+    "CachePolicyListTypeDef",
+    "CachePolicyQueryStringsConfigTypeDef",
+    "CachePolicySummaryTypeDef",
+    "CachePolicyTypeDef",
     "CachedMethodsTypeDef",
     "CloudFrontOriginAccessIdentityConfigTypeDef",
     "CloudFrontOriginAccessIdentityListTypeDef",
@@ -47,6 +54,7 @@ __all__ = (
     "CustomOriginConfigTypeDef",
     "DefaultCacheBehaviorTypeDef",
     "DistributionConfigTypeDef",
+    "DistributionIdListTypeDef",
     "DistributionListTypeDef",
     "DistributionSummaryTypeDef",
     "DistributionTypeDef",
@@ -78,9 +86,17 @@ __all__ = (
     "OriginGroupMembersTypeDef",
     "OriginGroupTypeDef",
     "OriginGroupsTypeDef",
+    "OriginRequestPolicyConfigTypeDef",
+    "OriginRequestPolicyCookiesConfigTypeDef",
+    "OriginRequestPolicyHeadersConfigTypeDef",
+    "OriginRequestPolicyListTypeDef",
+    "OriginRequestPolicyQueryStringsConfigTypeDef",
+    "OriginRequestPolicySummaryTypeDef",
+    "OriginRequestPolicyTypeDef",
     "OriginSslProtocolsTypeDef",
     "OriginTypeDef",
     "OriginsTypeDef",
+    "ParametersInCacheKeyAndForwardedToOriginTypeDef",
     "PathsTypeDef",
     "PublicKeyConfigTypeDef",
     "PublicKeyListTypeDef",
@@ -90,6 +106,7 @@ __all__ = (
     "QueryArgProfileTypeDef",
     "QueryArgProfilesTypeDef",
     "QueryStringCacheKeysTypeDef",
+    "QueryStringNamesTypeDef",
     "RestrictionsTypeDef",
     "S3OriginConfigTypeDef",
     "S3OriginTypeDef",
@@ -104,16 +121,20 @@ __all__ = (
     "TagsTypeDef",
     "TrustedSignersTypeDef",
     "ViewerCertificateTypeDef",
+    "CreateCachePolicyResultTypeDef",
     "CreateCloudFrontOriginAccessIdentityResultTypeDef",
     "CreateDistributionResultTypeDef",
     "CreateDistributionWithTagsResultTypeDef",
     "CreateFieldLevelEncryptionConfigResultTypeDef",
     "CreateFieldLevelEncryptionProfileResultTypeDef",
     "CreateInvalidationResultTypeDef",
+    "CreateOriginRequestPolicyResultTypeDef",
     "CreatePublicKeyResultTypeDef",
     "CreateStreamingDistributionResultTypeDef",
     "CreateStreamingDistributionWithTagsResultTypeDef",
     "DistributionConfigWithTagsTypeDef",
+    "GetCachePolicyConfigResultTypeDef",
+    "GetCachePolicyResultTypeDef",
     "GetCloudFrontOriginAccessIdentityConfigResultTypeDef",
     "GetCloudFrontOriginAccessIdentityResultTypeDef",
     "GetDistributionConfigResultTypeDef",
@@ -123,26 +144,34 @@ __all__ = (
     "GetFieldLevelEncryptionProfileResultTypeDef",
     "GetFieldLevelEncryptionResultTypeDef",
     "GetInvalidationResultTypeDef",
+    "GetOriginRequestPolicyConfigResultTypeDef",
+    "GetOriginRequestPolicyResultTypeDef",
     "GetPublicKeyConfigResultTypeDef",
     "GetPublicKeyResultTypeDef",
     "GetStreamingDistributionConfigResultTypeDef",
     "GetStreamingDistributionResultTypeDef",
+    "ListCachePoliciesResultTypeDef",
     "ListCloudFrontOriginAccessIdentitiesResultTypeDef",
+    "ListDistributionsByCachePolicyIdResultTypeDef",
+    "ListDistributionsByOriginRequestPolicyIdResultTypeDef",
     "ListDistributionsByWebACLIdResultTypeDef",
     "ListDistributionsResultTypeDef",
     "ListFieldLevelEncryptionConfigsResultTypeDef",
     "ListFieldLevelEncryptionProfilesResultTypeDef",
     "ListInvalidationsResultTypeDef",
+    "ListOriginRequestPoliciesResultTypeDef",
     "ListPublicKeysResultTypeDef",
     "ListStreamingDistributionsResultTypeDef",
     "ListTagsForResourceResultTypeDef",
     "PaginatorConfigTypeDef",
     "StreamingDistributionConfigWithTagsTypeDef",
     "TagKeysTypeDef",
+    "UpdateCachePolicyResultTypeDef",
     "UpdateCloudFrontOriginAccessIdentityResultTypeDef",
     "UpdateDistributionResultTypeDef",
     "UpdateFieldLevelEncryptionConfigResultTypeDef",
     "UpdateFieldLevelEncryptionProfileResultTypeDef",
+    "UpdateOriginRequestPolicyResultTypeDef",
     "UpdatePublicKeyResultTypeDef",
     "UpdateStreamingDistributionResultTypeDef",
     "WaiterConfigTypeDef",
@@ -197,10 +226,8 @@ _RequiredCacheBehaviorTypeDef = TypedDict(
     {
         "PathPattern": str,
         "TargetOriginId": str,
-        "ForwardedValues": "ForwardedValuesTypeDef",
         "TrustedSigners": "TrustedSignersTypeDef",
         "ViewerProtocolPolicy": Literal["allow-all", "https-only", "redirect-to-https"],
-        "MinTTL": int,
     },
 )
 _OptionalCacheBehaviorTypeDef = TypedDict(
@@ -208,11 +235,15 @@ _OptionalCacheBehaviorTypeDef = TypedDict(
     {
         "AllowedMethods": "AllowedMethodsTypeDef",
         "SmoothStreaming": bool,
-        "DefaultTTL": int,
-        "MaxTTL": int,
         "Compress": bool,
         "LambdaFunctionAssociations": "LambdaFunctionAssociationsTypeDef",
         "FieldLevelEncryptionId": str,
+        "CachePolicyId": str,
+        "OriginRequestPolicyId": str,
+        "ForwardedValues": "ForwardedValuesTypeDef",
+        "MinTTL": int,
+        "DefaultTTL": int,
+        "MaxTTL": int,
     },
     total=False,
 )
@@ -232,6 +263,97 @@ class CacheBehaviorsTypeDef(_RequiredCacheBehaviorsTypeDef, _OptionalCacheBehavi
     pass
 
 
+_RequiredCachePolicyConfigTypeDef = TypedDict(
+    "_RequiredCachePolicyConfigTypeDef", {"Name": str, "MinTTL": int}
+)
+_OptionalCachePolicyConfigTypeDef = TypedDict(
+    "_OptionalCachePolicyConfigTypeDef",
+    {
+        "Comment": str,
+        "DefaultTTL": int,
+        "MaxTTL": int,
+        "ParametersInCacheKeyAndForwardedToOrigin": "ParametersInCacheKeyAndForwardedToOriginTypeDef",
+    },
+    total=False,
+)
+
+
+class CachePolicyConfigTypeDef(
+    _RequiredCachePolicyConfigTypeDef, _OptionalCachePolicyConfigTypeDef
+):
+    pass
+
+
+_RequiredCachePolicyCookiesConfigTypeDef = TypedDict(
+    "_RequiredCachePolicyCookiesConfigTypeDef",
+    {"CookieBehavior": Literal["none", "whitelist", "allExcept", "all"]},
+)
+_OptionalCachePolicyCookiesConfigTypeDef = TypedDict(
+    "_OptionalCachePolicyCookiesConfigTypeDef", {"Cookies": "CookieNamesTypeDef"}, total=False
+)
+
+
+class CachePolicyCookiesConfigTypeDef(
+    _RequiredCachePolicyCookiesConfigTypeDef, _OptionalCachePolicyCookiesConfigTypeDef
+):
+    pass
+
+
+_RequiredCachePolicyHeadersConfigTypeDef = TypedDict(
+    "_RequiredCachePolicyHeadersConfigTypeDef", {"HeaderBehavior": Literal["none", "whitelist"]}
+)
+_OptionalCachePolicyHeadersConfigTypeDef = TypedDict(
+    "_OptionalCachePolicyHeadersConfigTypeDef", {"Headers": "HeadersTypeDef"}, total=False
+)
+
+
+class CachePolicyHeadersConfigTypeDef(
+    _RequiredCachePolicyHeadersConfigTypeDef, _OptionalCachePolicyHeadersConfigTypeDef
+):
+    pass
+
+
+_RequiredCachePolicyListTypeDef = TypedDict(
+    "_RequiredCachePolicyListTypeDef", {"MaxItems": int, "Quantity": int}
+)
+_OptionalCachePolicyListTypeDef = TypedDict(
+    "_OptionalCachePolicyListTypeDef",
+    {"NextMarker": str, "Items": List["CachePolicySummaryTypeDef"]},
+    total=False,
+)
+
+
+class CachePolicyListTypeDef(_RequiredCachePolicyListTypeDef, _OptionalCachePolicyListTypeDef):
+    pass
+
+
+_RequiredCachePolicyQueryStringsConfigTypeDef = TypedDict(
+    "_RequiredCachePolicyQueryStringsConfigTypeDef",
+    {"QueryStringBehavior": Literal["none", "whitelist", "allExcept", "all"]},
+)
+_OptionalCachePolicyQueryStringsConfigTypeDef = TypedDict(
+    "_OptionalCachePolicyQueryStringsConfigTypeDef",
+    {"QueryStrings": "QueryStringNamesTypeDef"},
+    total=False,
+)
+
+
+class CachePolicyQueryStringsConfigTypeDef(
+    _RequiredCachePolicyQueryStringsConfigTypeDef, _OptionalCachePolicyQueryStringsConfigTypeDef
+):
+    pass
+
+
+CachePolicySummaryTypeDef = TypedDict(
+    "CachePolicySummaryTypeDef",
+    {"Type": Literal["managed", "custom"], "CachePolicy": "CachePolicyTypeDef"},
+)
+
+CachePolicyTypeDef = TypedDict(
+    "CachePolicyTypeDef",
+    {"Id": str, "LastModifiedTime": datetime, "CachePolicyConfig": "CachePolicyConfigTypeDef"},
+)
+
 CachedMethodsTypeDef = TypedDict(
     "CachedMethodsTypeDef",
     {
@@ -420,10 +542,8 @@ _RequiredDefaultCacheBehaviorTypeDef = TypedDict(
     "_RequiredDefaultCacheBehaviorTypeDef",
     {
         "TargetOriginId": str,
-        "ForwardedValues": "ForwardedValuesTypeDef",
         "TrustedSigners": "TrustedSignersTypeDef",
         "ViewerProtocolPolicy": Literal["allow-all", "https-only", "redirect-to-https"],
-        "MinTTL": int,
     },
 )
 _OptionalDefaultCacheBehaviorTypeDef = TypedDict(
@@ -431,11 +551,15 @@ _OptionalDefaultCacheBehaviorTypeDef = TypedDict(
     {
         "AllowedMethods": "AllowedMethodsTypeDef",
         "SmoothStreaming": bool,
-        "DefaultTTL": int,
-        "MaxTTL": int,
         "Compress": bool,
         "LambdaFunctionAssociations": "LambdaFunctionAssociationsTypeDef",
         "FieldLevelEncryptionId": str,
+        "CachePolicyId": str,
+        "OriginRequestPolicyId": str,
+        "ForwardedValues": "ForwardedValuesTypeDef",
+        "MinTTL": int,
+        "DefaultTTL": int,
+        "MaxTTL": int,
     },
     total=False,
 )
@@ -483,6 +607,21 @@ class DistributionConfigTypeDef(
     pass
 
 
+_RequiredDistributionIdListTypeDef = TypedDict(
+    "_RequiredDistributionIdListTypeDef",
+    {"Marker": str, "MaxItems": int, "IsTruncated": bool, "Quantity": int},
+)
+_OptionalDistributionIdListTypeDef = TypedDict(
+    "_OptionalDistributionIdListTypeDef", {"NextMarker": str, "Items": List[str]}, total=False
+)
+
+
+class DistributionIdListTypeDef(
+    _RequiredDistributionIdListTypeDef, _OptionalDistributionIdListTypeDef
+):
+    pass
+
+
 _RequiredDistributionListTypeDef = TypedDict(
     "_RequiredDistributionListTypeDef",
     {"Marker": str, "MaxItems": int, "IsTruncated": bool, "Quantity": int},
@@ -865,6 +1004,112 @@ class OriginGroupsTypeDef(_RequiredOriginGroupsTypeDef, _OptionalOriginGroupsTyp
     pass
 
 
+_RequiredOriginRequestPolicyConfigTypeDef = TypedDict(
+    "_RequiredOriginRequestPolicyConfigTypeDef",
+    {
+        "Name": str,
+        "HeadersConfig": "OriginRequestPolicyHeadersConfigTypeDef",
+        "CookiesConfig": "OriginRequestPolicyCookiesConfigTypeDef",
+        "QueryStringsConfig": "OriginRequestPolicyQueryStringsConfigTypeDef",
+    },
+)
+_OptionalOriginRequestPolicyConfigTypeDef = TypedDict(
+    "_OptionalOriginRequestPolicyConfigTypeDef", {"Comment": str}, total=False
+)
+
+
+class OriginRequestPolicyConfigTypeDef(
+    _RequiredOriginRequestPolicyConfigTypeDef, _OptionalOriginRequestPolicyConfigTypeDef
+):
+    pass
+
+
+_RequiredOriginRequestPolicyCookiesConfigTypeDef = TypedDict(
+    "_RequiredOriginRequestPolicyCookiesConfigTypeDef",
+    {"CookieBehavior": Literal["none", "whitelist", "all"]},
+)
+_OptionalOriginRequestPolicyCookiesConfigTypeDef = TypedDict(
+    "_OptionalOriginRequestPolicyCookiesConfigTypeDef",
+    {"Cookies": "CookieNamesTypeDef"},
+    total=False,
+)
+
+
+class OriginRequestPolicyCookiesConfigTypeDef(
+    _RequiredOriginRequestPolicyCookiesConfigTypeDef,
+    _OptionalOriginRequestPolicyCookiesConfigTypeDef,
+):
+    pass
+
+
+_RequiredOriginRequestPolicyHeadersConfigTypeDef = TypedDict(
+    "_RequiredOriginRequestPolicyHeadersConfigTypeDef",
+    {
+        "HeaderBehavior": Literal[
+            "none", "whitelist", "allViewer", "allViewerAndWhitelistCloudFront"
+        ]
+    },
+)
+_OptionalOriginRequestPolicyHeadersConfigTypeDef = TypedDict(
+    "_OptionalOriginRequestPolicyHeadersConfigTypeDef", {"Headers": "HeadersTypeDef"}, total=False
+)
+
+
+class OriginRequestPolicyHeadersConfigTypeDef(
+    _RequiredOriginRequestPolicyHeadersConfigTypeDef,
+    _OptionalOriginRequestPolicyHeadersConfigTypeDef,
+):
+    pass
+
+
+_RequiredOriginRequestPolicyListTypeDef = TypedDict(
+    "_RequiredOriginRequestPolicyListTypeDef", {"MaxItems": int, "Quantity": int}
+)
+_OptionalOriginRequestPolicyListTypeDef = TypedDict(
+    "_OptionalOriginRequestPolicyListTypeDef",
+    {"NextMarker": str, "Items": List["OriginRequestPolicySummaryTypeDef"]},
+    total=False,
+)
+
+
+class OriginRequestPolicyListTypeDef(
+    _RequiredOriginRequestPolicyListTypeDef, _OptionalOriginRequestPolicyListTypeDef
+):
+    pass
+
+
+_RequiredOriginRequestPolicyQueryStringsConfigTypeDef = TypedDict(
+    "_RequiredOriginRequestPolicyQueryStringsConfigTypeDef",
+    {"QueryStringBehavior": Literal["none", "whitelist", "all"]},
+)
+_OptionalOriginRequestPolicyQueryStringsConfigTypeDef = TypedDict(
+    "_OptionalOriginRequestPolicyQueryStringsConfigTypeDef",
+    {"QueryStrings": "QueryStringNamesTypeDef"},
+    total=False,
+)
+
+
+class OriginRequestPolicyQueryStringsConfigTypeDef(
+    _RequiredOriginRequestPolicyQueryStringsConfigTypeDef,
+    _OptionalOriginRequestPolicyQueryStringsConfigTypeDef,
+):
+    pass
+
+
+OriginRequestPolicySummaryTypeDef = TypedDict(
+    "OriginRequestPolicySummaryTypeDef",
+    {"Type": Literal["managed", "custom"], "OriginRequestPolicy": "OriginRequestPolicyTypeDef"},
+)
+
+OriginRequestPolicyTypeDef = TypedDict(
+    "OriginRequestPolicyTypeDef",
+    {
+        "Id": str,
+        "LastModifiedTime": datetime,
+        "OriginRequestPolicyConfig": "OriginRequestPolicyConfigTypeDef",
+    },
+)
+
 OriginSslProtocolsTypeDef = TypedDict(
     "OriginSslProtocolsTypeDef",
     {"Quantity": int, "Items": List[Literal["SSLv3", "TLSv1", "TLSv1.1", "TLSv1.2"]]},
@@ -891,6 +1136,16 @@ class OriginTypeDef(_RequiredOriginTypeDef, _OptionalOriginTypeDef):
 
 OriginsTypeDef = TypedDict("OriginsTypeDef", {"Quantity": int, "Items": List["OriginTypeDef"]})
 
+ParametersInCacheKeyAndForwardedToOriginTypeDef = TypedDict(
+    "ParametersInCacheKeyAndForwardedToOriginTypeDef",
+    {
+        "EnableAcceptEncodingGzip": bool,
+        "HeadersConfig": "CachePolicyHeadersConfigTypeDef",
+        "CookiesConfig": "CachePolicyCookiesConfigTypeDef",
+        "QueryStringsConfig": "CachePolicyQueryStringsConfigTypeDef",
+    },
+)
+
 _RequiredPathsTypeDef = TypedDict("_RequiredPathsTypeDef", {"Quantity": int})
 _OptionalPathsTypeDef = TypedDict("_OptionalPathsTypeDef", {"Items": List[str]}, total=False)
 
@@ -985,6 +1240,16 @@ class QueryStringCacheKeysTypeDef(
     pass
 
 
+_RequiredQueryStringNamesTypeDef = TypedDict("_RequiredQueryStringNamesTypeDef", {"Quantity": int})
+_OptionalQueryStringNamesTypeDef = TypedDict(
+    "_OptionalQueryStringNamesTypeDef", {"Items": List[str]}, total=False
+)
+
+
+class QueryStringNamesTypeDef(_RequiredQueryStringNamesTypeDef, _OptionalQueryStringNamesTypeDef):
+    pass
+
+
 RestrictionsTypeDef = TypedDict("RestrictionsTypeDef", {"GeoRestriction": "GeoRestrictionTypeDef"})
 
 S3OriginConfigTypeDef = TypedDict("S3OriginConfigTypeDef", {"OriginAccessIdentity": str})
@@ -1122,6 +1387,12 @@ ViewerCertificateTypeDef = TypedDict(
     total=False,
 )
 
+CreateCachePolicyResultTypeDef = TypedDict(
+    "CreateCachePolicyResultTypeDef",
+    {"CachePolicy": "CachePolicyTypeDef", "Location": str, "ETag": str},
+    total=False,
+)
+
 CreateCloudFrontOriginAccessIdentityResultTypeDef = TypedDict(
     "CreateCloudFrontOriginAccessIdentityResultTypeDef",
     {
@@ -1166,6 +1437,12 @@ CreateInvalidationResultTypeDef = TypedDict(
     total=False,
 )
 
+CreateOriginRequestPolicyResultTypeDef = TypedDict(
+    "CreateOriginRequestPolicyResultTypeDef",
+    {"OriginRequestPolicy": "OriginRequestPolicyTypeDef", "Location": str, "ETag": str},
+    total=False,
+)
+
 CreatePublicKeyResultTypeDef = TypedDict(
     "CreatePublicKeyResultTypeDef",
     {"PublicKey": "PublicKeyTypeDef", "Location": str, "ETag": str},
@@ -1189,6 +1466,16 @@ DistributionConfigWithTagsTypeDef = TypedDict(
     {"DistributionConfig": "DistributionConfigTypeDef", "Tags": "TagsTypeDef"},
 )
 
+GetCachePolicyConfigResultTypeDef = TypedDict(
+    "GetCachePolicyConfigResultTypeDef",
+    {"CachePolicyConfig": "CachePolicyConfigTypeDef", "ETag": str},
+    total=False,
+)
+
+GetCachePolicyResultTypeDef = TypedDict(
+    "GetCachePolicyResultTypeDef", {"CachePolicy": "CachePolicyTypeDef", "ETag": str}, total=False
+)
+
 GetCloudFrontOriginAccessIdentityConfigResultTypeDef = TypedDict(
     "GetCloudFrontOriginAccessIdentityConfigResultTypeDef",
     {
@@ -1244,6 +1531,18 @@ GetInvalidationResultTypeDef = TypedDict(
     "GetInvalidationResultTypeDef", {"Invalidation": "InvalidationTypeDef"}, total=False
 )
 
+GetOriginRequestPolicyConfigResultTypeDef = TypedDict(
+    "GetOriginRequestPolicyConfigResultTypeDef",
+    {"OriginRequestPolicyConfig": "OriginRequestPolicyConfigTypeDef", "ETag": str},
+    total=False,
+)
+
+GetOriginRequestPolicyResultTypeDef = TypedDict(
+    "GetOriginRequestPolicyResultTypeDef",
+    {"OriginRequestPolicy": "OriginRequestPolicyTypeDef", "ETag": str},
+    total=False,
+)
+
 GetPublicKeyConfigResultTypeDef = TypedDict(
     "GetPublicKeyConfigResultTypeDef",
     {"PublicKeyConfig": "PublicKeyConfigTypeDef", "ETag": str},
@@ -1266,12 +1565,28 @@ GetStreamingDistributionResultTypeDef = TypedDict(
     total=False,
 )
 
+ListCachePoliciesResultTypeDef = TypedDict(
+    "ListCachePoliciesResultTypeDef", {"CachePolicyList": "CachePolicyListTypeDef"}, total=False
+)
+
 ListCloudFrontOriginAccessIdentitiesResultTypeDef = TypedDict(
     "ListCloudFrontOriginAccessIdentitiesResultTypeDef",
     {"CloudFrontOriginAccessIdentityList": "CloudFrontOriginAccessIdentityListTypeDef"},
     total=False,
 )
 
+ListDistributionsByCachePolicyIdResultTypeDef = TypedDict(
+    "ListDistributionsByCachePolicyIdResultTypeDef",
+    {"DistributionIdList": "DistributionIdListTypeDef"},
+    total=False,
+)
+
+ListDistributionsByOriginRequestPolicyIdResultTypeDef = TypedDict(
+    "ListDistributionsByOriginRequestPolicyIdResultTypeDef",
+    {"DistributionIdList": "DistributionIdListTypeDef"},
+    total=False,
+)
+
 ListDistributionsByWebACLIdResultTypeDef = TypedDict(
     "ListDistributionsByWebACLIdResultTypeDef",
     {"DistributionList": "DistributionListTypeDef"},
@@ -1298,6 +1613,12 @@ ListInvalidationsResultTypeDef = TypedDict(
     "ListInvalidationsResultTypeDef", {"InvalidationList": "InvalidationListTypeDef"}, total=False
 )
 
+ListOriginRequestPoliciesResultTypeDef = TypedDict(
+    "ListOriginRequestPoliciesResultTypeDef",
+    {"OriginRequestPolicyList": "OriginRequestPolicyListTypeDef"},
+    total=False,
+)
+
 ListPublicKeysResultTypeDef = TypedDict(
     "ListPublicKeysResultTypeDef", {"PublicKeyList": "PublicKeyListTypeDef"}, total=False
 )
@@ -1323,6 +1644,12 @@ StreamingDistributionConfigWithTagsTypeDef = TypedDict(
 
 TagKeysTypeDef = TypedDict("TagKeysTypeDef", {"Items": List[str]}, total=False)
 
+UpdateCachePolicyResultTypeDef = TypedDict(
+    "UpdateCachePolicyResultTypeDef",
+    {"CachePolicy": "CachePolicyTypeDef", "ETag": str},
+    total=False,
+)
+
 UpdateCloudFrontOriginAccessIdentityResultTypeDef = TypedDict(
     "UpdateCloudFrontOriginAccessIdentityResultTypeDef",
     {"CloudFrontOriginAccessIdentity": "CloudFrontOriginAccessIdentityTypeDef", "ETag": str},
@@ -1347,6 +1674,12 @@ UpdateFieldLevelEncryptionProfileResultTypeDef = TypedDict(
     total=False,
 )
 
+UpdateOriginRequestPolicyResultTypeDef = TypedDict(
+    "UpdateOriginRequestPolicyResultTypeDef",
+    {"OriginRequestPolicy": "OriginRequestPolicyTypeDef", "ETag": str},
+    total=False,
+)
+
 UpdatePublicKeyResultTypeDef = TypedDict(
     "UpdatePublicKeyResultTypeDef", {"PublicKey": "PublicKeyTypeDef", "ETag": str}, total=False
 )
